@@ -28,9 +28,16 @@ class IConfigurationService(Interface):
             'name' is either a full dotted name or added to a dotted
              prefix.
         """
+
     def getConfiguration():
         """ Return all configuration items as dict """
 
+    def getConfigurationForPrefix(prefix):
+        """ Return all configuration items as dict for a given prefix"""
+
+    def shutdown():
+        """ Perform actions upon system shutdown """
+
 
 class IConfigurationChangedEvent(Interface):
     """ Event send upon configuration changes """
