@@ -14,6 +14,7 @@ import time
 import cfgparse
 import zope.event
 import threading
+import time
 from sets import Set
 from decorator import synchronized
 from zope.component.interfaces import IFactory
@@ -49,7 +50,7 @@ class ConfigurationService(object):
         self.notify_wm = None
         self.notifier = None
         if self.watch and have_pyinotify:
-            self.notify_mask = EventsCodes.IN_MODIFY | EventsCodes.IN_DELETE | EventsCodes.IN_ATTRIB |  EventsCodes.IN_CREATE
+            self.notify_mask = EventsCodes.IN_MODIFY | EventsCodes.IN_DELETE | EventsCodes.IN_ATTRIB |  EventsCodes.IN_CREATE | EventsCodes.IN_MOVE_SELF
             self.notify_wm = WatchManager()
             event_handler = NotificationEvent()
             event_handler.setService(self) # needed for callback
@@ -67,7 +68,7 @@ class ConfigurationService(object):
         filename = os.path.abspath(filename)
         if not os.path.exists(filename):
             raise IOError('Mode file %s does not exist' % filename)
-        LOG.debug('register model: %s' % filename)
+        LOG.info('register model: %s' % filename)
         self.model_files.add(filename)
 
     def loadConfiguration(self, filename):
@@ -77,13 +78,13 @@ class ConfigurationService(object):
         filename = os.path.abspath(filename)
         if not os.path.exists(filename):
             raise IOError('Configuration file %s does not exist' % filename)
-        LOG.debug('loading configuration: %s' % filename)
+        LOG.info('loading configuration: %s' % filename)
         self.configuration_files.add(filename)
         self.reload()
 
         if self.watch and have_pyinotify:
             # watch path for events handled by mask.
-            LOG.debug('watching %s' % filename)
+            LOG.info('watching %s' % filename)
             self.notify_wm.add_watch(filename, self.notify_mask)
 
     @synchronized(lock)
@@ -94,6 +95,11 @@ class ConfigurationService(object):
             LOG.error('Reloading the configuration failed', exc_info=True)
             return
 
+        if self.watch and have_pyinotify:
+            # re-add watches
+            for filename in self.configuration_files:
+                self.notify_wm.add_watch(filename, self.notify_mask)
+
         self.last_reload = time.time()
         zope.event.notify(ConfigurationChangedEvent(self.getConfiguration()))
 
@@ -101,7 +107,7 @@ class ConfigurationService(object):
     def _reload(self):
         """ Reload models and configuration """
 
-        LOG.debug('Reloading configuration')
+        LOG.info('Reloading configuration')
         # create a new parser first (w/o overriding the original one)
         parser = cfgparse.ConfigParser()
 
@@ -176,7 +182,8 @@ if have_pyinotify:
             self.service = service
 
         def process_default(self, event):
-            LOG.debug('Configuration file changed: %s' % event.path)
+            LOG.info('Configuration file changed: %s' % event.path)
+            time.sleep(5)
             self.service.reload()
 
 
